const Redis = require('ioredis');

const XCEBikeDevice = require('./ebike/XCEBikeDevice');
const XCEBikeTicketClass = require('./ebike/XCEBikeTicket');
const XCEBikeTicket = XCEBikeTicketClass.XCEBikeTicket;
const XCEBikeAlarmTicket = XCEBikeTicketClass.XCEBikeAlarmTicket;
const XCEBikeFixTicket = XCEBikeTicketClass.XCEBikeFixTicket;
const XCEBikeUser = require('./ebike/XCEBikeUser');
const XCEBikeUserOrder = require('./ebike/XCEBikeUserOrder');
const XCEBikeGFence = require('./ebike/XCEBikeGFence');
const XCEBikeToolsPermission = require('./ebike/XCEBikeToolsPermission').XCEBikeToolsPermission;


/**
 * 配置数据库的方法
 */
function config(redisClient, sequelizeInstance, yuntu) {

    if (redisClient == null || sequelizeInstance == null || yuntu == null) {
        throw 'redisClient或RDS实例不能为空';
    }
    //根据redis配置new一个redis sub
    let redisSubClient = new Redis(redisClient.options);
    if (redisSubClient == null) {
        throw 'redisSubClient创建失败';
    }

    XCEBikeDevice.configRedis(redisClient, redisSubClient);
    XCEBikeDevice.configSequelize(sequelizeInstance);
    XCEBikeDevice.configYuntu(yuntu);

    XCEBikeTicket.configRedis(redisClient, redisSubClient);
    XCEBikeTicket.configSequelize(sequelizeInstance);

    XCEBikeUser.configRedis(redisClient, redisSubClient);
    XCEBikeUser.configSequelize(sequelizeInstance);

    XCEBikeUserOrder.configRedis(redisClient, redisSubClient);
    XCEBikeUserOrder.configSequelize(sequelizeInstance);

    XCEBikeGFence.configRedis(redisClient, redisSubClient);
    XCEBikeGFence.configSequelize(sequelizeInstance);
    XCEBikeGFence.configYuntu(yuntu);

    XCEBikeToolsPermission.configSequelize(sequelizeInstance);

}


module.exports = {
    config,
    XCEBikeDevice, //设备操作类
    XCEBikeUser, //用户操作类
    XCEBikeUserOrder, //用户订单操作类
    XCEBikeTicket, //工单操作类,3个
    XCEBikeAlarmTicket,
    XCEBikeFixTicket,
    XCEBikeGFence, //电子围栏操作类
    
    XCEBikeToolsPermission,
}